import React from 'react';
import { Link } from 'react-router-dom';
import { Card, Row, Col, Icon, Form, Input, Button, Select, Table, DatePicker, message, Breadcrumb, Layout, Modal, Pagination, Divider } from 'antd';
import TableView from '../../common/TableView';
import SearchFormView from '../../common/SearchFormView';
import moment from 'moment';
import fetch from '../../../api/request';

const FormItem = Form.Item;
const Option = Select.Option;
const confirm = Modal.confirm;


class UserManage extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      formData: {
        __key: Date.now(),
        type: '',
        title: '',
        page: 1,
        size: 10,
      },
    };
  }

  componentDidMount() { }

  setFormData = data => {
    console.log('form', data);
    this.setState({
      formData: data,
    });
  }

  render() {
    const { formData } = this.state;
    let tableParams = {
      url: `api/user/query`,
      formData,
      key: formData.__key,
      columns: this.renderColumns(),
      extraFromData: {
        type: 'DT00002',
      },
      setFormData: this.setFormData
    }

    return (
      <div className="usermanage-main margin padding bg-white">
        <SearchFormView
          formData={formData}
          setFormData={this.setFormData}
          data={[
            { type: 'input', name: '姓名', label: '姓名', key: 'trueName' },
            { type: 'input', name: '身份证号码', label: '身份证号码', key: 'idcard' },
            { type: 'input', name: '手机号码', label: '手机号码', key: 'mobile' },
            { type: 'input', name: '电子邮箱', label: '电子邮箱', key: 'email' },
          ]} />
        <Row type="flex" gutter={20} className="margin-bottom"> 
          <Col>
            <Button type="primary">同步微信用户</Button>
          </Col>
          <Col>
            <Button type="primary">新增用户</Button>
          </Col>
        </Row>
        <TableView {...tableParams} />
      </div>
    )
  }

  // 新增用户
  add = () => {
    this.props.history.push('/baseManage/userDetail/new/Add')
  }
  // 删除用户
  onDel = (_text, _record) => {
    // Fetch.userDel({ ids: _text.id }).then(res => {
    //   if (res.code == 0) {
    //     message.warning('正在更新列表');
    //     this.loadData(1, this.state.pageSize);
    //   }
    // }, err => {
    //   message.error(err);
    // });
  }

  renderColumns = () => {
    let obj = this;
    return [
      { title: '头像', className: "txt-c", dataIndex: 'avatar', key: 'avatar', render: (text, record) => text ? <img style={{ height: 23, width: 25 }} src={text} /> : <Icon type="user-delete" style={{ fontSize: 20 }} /> },
      { title: '姓名', className: "txt-c", dataIndex: 'trueName', key: 'trueName' },
      { title: '身份证', className: "txt-c", dataIndex: 'idcard', key: 'idcard' },
      { title: '邮箱', className: "txt-c", dataIndex: 'email', key: 'email' },
      { title: '手机号码', className: "txt-c", dataIndex: 'mobile', key: 'mobile' },
      { title: '创建时间', className: "txt-c", dataIndex: 'createTime', key: 'createTime', render: (text, record) => text !== "" && text != null ? moment(text).format("YYYY-MM-DD HH:mm") : "" },
      {
        title: '操作', className: "txt-c", key: 'operation', render: (text, record) => {
          return <div>
            <Link to={{ pathname: "/baseManage/userDetail/" + record.id + '/Modify', query: { id: record.id } }}>修改</Link>
            <Divider type="vertical" />
            <a onClick={() => this.delete(record.id)}>删除</a>
          </div>
        }
      }
    ]
  }
  delete = (id) => {
    let _this = this;
    confirm({
      title: <span style={{ fontSize: 19 }}>确定要删除该用户吗？</span>,
      onOk() {
        // Fetch.userDel({ ids: id }).then(res => {
        //   if (res.code == 0) {
        //     message.success("删除成功")
        //     _this.loadData(1, _this.state.pageSize);
        //   }
        // }, err => {
        //   message.error(err);
        // });
      },
      onCancel() { },
    });
  }
  userSync = () => {
    let _this = this;
    this.setState({ loading: true })
    // syncCpUser().then(res => {
    //   if (res.code == 0) {
    //     _this.loadData(1, this.state.pageSize)
    //     _this.setState({
    //       loading: false
    //     });
    //     message.success("同步成功！");
    //   } else {
    //     message.error("操作失败，请联系管理员");
    //     this.setState({ spinning: false })
    //   }
    // })
  }

}

const UserManageList = Form.create()(UserManage);
export default UserManageList;